use config::CuddleConfig;
use simplelog::{ColorChoice, Config, TermLogger, TerminalMode};

mod actions;
mod cli;
mod config;
mod context;
mod model;

fn main() -> anyhow::Result<()> {
    TermLogger::init(
        log::LevelFilter::Info,
        Config::default(),
        TerminalMode::Mixed,
        ColorChoice::Auto,
    )?;

    log::set_max_level(log::LevelFilter::Info);

    let config = CuddleConfig::from_env()?;

    let context = context::extract_cuddle(config.clone())?;
    _ = cli::CuddleCli::new(context)?.execute()?;

    Ok(())
}
